#!/bin/csh

if ( $?_HPX_SEEN_HEP_CSH_CSHRC ) then
	exit
endif
set _HPX_SEEN_HEP_CSH_CSHRC=1

if ( ! $?HPX_INIT ) then
	if ( $?HPX_HOME_CORE ) then
		source $HPX_HOME_CORE/init.csh
	else
		source /etc/hepix/init.csh
	endif
endif

# NOTE(fuji): sh(1) derivatives source `pathtools' here, but we have to
# define aliases to emulated shell functions for csh(1).  See csh/CORE/init
# for explanation.
alias hpx_path_is_present	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_is_present.csh "
alias hpx_path_remove		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_remove.csh "
alias hpx_path_prepend		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_prepend.csh "
alias hpx_path_prepend_unique	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_prepend_unique.csh "
alias hpx_path_prepend_unless_present	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_prepend_unless_present.csh "
alias hpx_path_append		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_append.csh "
alias hpx_path_append_unique	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_append_unique.csh "
alias hpx_path_append_unless_present	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_append_unless_present.csh "

umask $HPX_UMASK

# Determine HEP group name.
set HPX_PREF_GROUP=$HPX_USER_HOME/preferred-group
set HPX_HEPGROUP=$HPX_NONE
if ( -r $HPX_PREF_GROUP) then
	set HPX_HEPGROUP=`/bin/cat $HPX_PREF_GROUP`
else
	### OBSOLETE ### set HPX_HEPGROUP=`/usr/bin/id | $HPXB_SED -n 's/^[^ ]\{1,\}[^(]\{1,\}(\([^)]\{1,\}\).*$/\1/p'`
	set HPX_HEPGROUP=`/usr/bin/id -gn`
endif
if ( "x$HPX_HEPGROUP" == x ) then
	set HPX_HEPGROUP=$HPX_NONE
endif

### OBSOLETE ### hpx_source $HPX_HOME_SITE/csh.cshrc
if ( ! $?HPX_INIT ) then
	if ( $?HPX_HOME_CORE ) then
		source $HPX_HOME_CORE/init.csh
	else
		source /etc/hepix/init.csh
	endif
endif

# Determine HEP group directory.  Defaults to AFS.
if ( -d /afs/cern.ch/group/$HPX_HEPGROUP ) then
        setenv GROUP_DIR/afs/cern.ch/group/$HPX_HEPGROUP
endif

# Sanitize and set site-wide environment variables.

set HPX_INITIALE=`echo $USER | /usr/bin/cut -c1`
setenv CASTOR_HOME /castor/cern.ch/user/$HPX_INITIALE/$USER
unset HPX_INITIALE

# NOTE(fuji): These are normally in the local namespace, but AFS
# group script maintainers tend to `setenv' these variables and
# then we have a namespace clash (no way to specify at dereference
# ($GROUPPATH) time which namespace to access.  See also ROOTPATH
# assignments.
# CT197070 Matthias Schröder <Matthias.Schroder@cern.ch>
if ( $?GROUP_DIR ) then
	setenv GROUPPATH $GROUP_DIR/bin
endif

### OBSOLETE ### hpx_source $HPX_SYSTEM_HOME/sys.conf.csh
if ( $?GROUP_DIR ) then
        hpx_source $GROUP_DIR/group_sys.conf.csh
endif
### OBSOLETE ### hpx_source $HPX_SYSTEM_HOME/env.csh
if ( $?GROUP_DIR ) then
        hpx_source $GROUP_DIR/group_env.csh
endif

if ( $?GROUPPATH ) then
	echo "$GROUPPATH" | /bin/grep ' ' >/dev/null
	if ( $status == 0 ) then
		hpx_debug "GROUPPATH contains obsolete space separator, use colons."
		setenv GROUPPATH `echo "$GROUPPATH" | /bin/sed 's/ /:/g'`
	endif
endif
if ( $?USERPATH ) then
	echo "$USERPATH" | /bin/grep ' ' >/dev/null
	if ( $status == 0 ) then
		hpx_debug "USERPATH contains obsolete space separator, use colons."
		setenv USERPATH `echo "$USERPATH" | /bin/sed 's/ /:/g'`
	endif
endif

if ( $?GROUPPATH ) then
        setenv USERPATH ${GROUPPATH}:${HOME}/scripts
else
        setenv USERPATH ${HOME}/scripts
endif
# Fix up paths that might contain $HPX_NONEs.
setenv USERPATH `echo $USERPATH | /bin/sed 's/:\?'$HPX_NONE':\?/:/g;s/^://;s/:$//;s/:\{1,\}/:/g'`

### OBSOLETE ### hpx_source $HPX_SYSTEM_HOME/aliases.csh
if ( $?GROUP_DIR ) then
        hpx_source $GROUP_DIR/group_aliases.csh
endif

### OBSOLETE ### hpx_source $HPX_SYSTEM_HOME/csh.cshrc
if ( $?GROUP_DIR ) then
        hpx_source $GROUP_DIR/group_csh.cshrc
endif

# Incorporate assembled entries into PATH.
set HPX_PATH=$USERPATH

# STEP 0. Append PATH to HPX_PATH and empty PATH, we're going
# to iterate over HPX_PATH and uniquely append to an (initially
# empty) PATH.

set HPX_PATH=${HPX_PATH}:${PATH}
setenv PATH ""

# STEP 1. Create a space-separated list from HPX_PATH using the shell's
# PATH<->path synchronization.
set _HPX_PATH_SAVE=$PATH
setenv PATH $HPX_PATH
set hpx_path=($path)
setenv PATH $_HPX_PATH_SAVE
unset _HPX_PATH_SAVE

# STEP 2. Emulate what hpx_path_append_unique() does in sh(1)-derivatives.
# NOTE(fuji): Let's try with our shiny pathtools implementation.
foreach HPX_DIR ($hpx_path)
## 	set c=1
## 	set found=0
## 	while ( ! $found && $c <= $#path )
## 		if ( $HPX_DIR == "$path[$c]" ) then
## 			set found=1
## 		endif
## 		@ c++
## 	end
## 	if ( ! found ) then
## 		set path=($path $HPX_DIR)
## 	endif
	eval `hpx_path_append_unless_present "$HPX_DIR"`
end
## unset c
## unset found

# STEP 3. Release outer level temporary variables, we're done.
unset HPX_DIR
unset hpx_path
unset HPX_PATH

hpx_source $HPX_HOME_HEP/${HPX_SHELL}rc

# End of file.
